@@ -1,6 +1,10 @@
+import enum
+import os
 from dataclasses import dataclass, field
 from typing import List, Optional, Union
 
+from dothttp import DotHttpException
+
 
 @dataclass
 class Allhttp:
@@ -38,6 +42,11 @@ class AwsAuthWrap:
     service: str
     region: Union[str, None]
 
+@dataclass
+class NtlmAuthWrap:
+    username: str
+    password: str
+
 
 @dataclass
 class AuthWrap:
@@ -45,6 +54,7 @@ class AuthWrap:
     digest_auth: Optional[DigestAuth] = None
     basic_auth: Optional[BasicAuth] = None
     aws_auth: Optional[AwsAuthWrap] = None
+    ntlm_auth: Optional[NtlmAuthWrap] = None
 
 
 @dataclass
@@ -371,3 +381,29 @@ AWS_SERVICES_LIST = {'acm',
                      'workmail',
                      'workspaces',
                      'xray'}
+
+
+class HttpFileType(enum.Enum):
+    Notebookfile = ("notebook", ("hnbk", "httpbook"))
+    Httpfile = ("http", ('http', 'dhttp'))
+
+    def __init__(self, typename, filetypes):
+        self.file_exts = filetypes
+        self.file_type = typename
+
+    @staticmethod
+    def get_from_filetype(filetype: str):
+        if filetype == HttpFileType.Notebookfile.file_type:
+            return HttpFileType.Notebookfile
+        return HttpFileType.Httpfile
+
+    @staticmethod
+    def get_format_from_file_name(filename: str):
+        _, ext = os.path.splitext(filename)
+        if ext and len(ext) > 0:
+            ext = ext[1:]
+        if ext in HttpFileType.Notebookfile.file_exts:
+            return HttpFileType.Notebookfile
+        elif ext in HttpFileType.Httpfile.file_exts:
+            return HttpFileType.Httpfile
+        raise DotHttpException("unknown file type")
