@@ -2,6 +2,7 @@ import functools
 import logging
 import os
 from http.cookiejar import LWPCookieJar
+from pprint import pprint
 from typing import Union
 from urllib.parse import urlparse, unquote, urlunparse
 
@@ -18,7 +19,7 @@ from . import eprint, Config, HttpDefBase, js3py, AWS4Auth
 from .curl_utils import to_curl
 from .dsl_jsonparser import json_or_array_to_json
 from .json_utils import JSONEncoder
-from .parse_models import Allhttp
+from .parse_models import Allhttp, Http, HttpFileType
 from .utils import quote_or_unquote, apply_quote_or_unquote
 
 JSON_ENCODER = JSONEncoder(indent=4)
@@ -61,6 +62,7 @@ def get_new_session():
 
 class RequestBase(HttpDefBase):
     global_session = get_new_session()
+    global_cookie_jar = None
 
     def __init__(self, args: Config):
         super().__init__(args)
@@ -76,6 +78,8 @@ class RequestBase(HttpDefBase):
             cookie = None
             request_logger.debug(f'cookies set to `{self.args.no_cookie}`')
         else:
+            if RequestBase.global_cookie_jar:
+                return RequestBase.global_cookie_jar
             cookie = LWPCookieJar(DOTHTTP_COOKIEJAR)
             request_logger.debug(f'cookie {cookie} loaded from {DOTHTTP_COOKIEJAR}')
             try:
@@ -92,7 +96,7 @@ class RequestBase(HttpDefBase):
                 # FUTURE
                 # instead of saving (short curiting here, could lead to bad logic error)
                 self.args.no_cookie = True
-        self._cookie = cookie
+        RequestBase.global_cookie_jar = self._cookie = cookie
         return self._cookie
 
     def get_session(self):
@@ -101,9 +105,8 @@ class RequestBase(HttpDefBase):
             # TODO
             return get_new_session()
         session = self.global_session
-        if not self.args.no_cookie:
-            if cookie := self.get_cookie():
-                session.cookies = cookie
+        # if not self.args.no_cookie:
+        #     session.cookies = self.get_cookie()
         # session.hooks['response'] = self.save_cookie_call_back
         return session
 
@@ -182,13 +185,17 @@ class CurlCompiler(RequestBase):
             else:
                 payload_parts += [('-d', payload.data)]
                 contenttype = TEXT_PLAIN
-            if contenttype and CONTENT_TYPE not in self.httpdef.headers:
+            if payload.header and contenttype and CONTENT_TYPE not in self.httpdef.headers:
                 self.httpdef.headers['content-type'] = payload.header
         # there few headers which set dynamically (basically auth)
         # so set headers in the end
         # if isinstance(self.httpdef.headers, AWS4Auth):
         for k, v in sorted(self.httpdef.headers.items()):
             parts += [('-H', '{0}: {1}'.format(k, v))]
+
+        if 'cookie' in prep.headers:
+            parts += [('-H', '{0}: {1}'.format('cookie', prep.headers['cookie'] ))]
+
         url = prep.url
 
         if url.startswith(UNIX_SOCKET_SCHEME):
@@ -220,9 +227,8 @@ class HttpFileFormatter(RequestBase):
         self.prop_cache = {}
 
     @staticmethod
-    def format(model: Allhttp):
-        output_str = ""
-        for http in model.allhttps:
+    def format_http(http: Http):
+            output_str = ""
             new_line = "\n"
             if getattr(http, "description", None):
                 for line in http.description.splitlines():
@@ -256,6 +262,8 @@ class HttpFileFormatter(RequestBase):
                     output_str += f'{new_line}basicauth("{basic_auth.username}", "{basic_auth.password}")'
                 elif digest_auth := auth_wrap.digest_auth:
                     output_str += f'{new_line}digestauth("{digest_auth.username}", "{digest_auth.password}")'
+                elif ntlm_auth := auth_wrap.ntlm_auth:
+                    output_str += f'{new_line}ntlmauth("{ntlm_auth.username}", "{ntlm_auth.password}")'
                 elif aws_auth := auth_wrap.aws_auth:
                     if aws_auth.service and aws_auth.region:
                         output_str += f'{new_line}awsauth(access_id="{aws_auth.access_id}", secret_key="{aws_auth.secret_token}", service="{aws_auth.service}", region="{aws_auth.region}")'
@@ -294,27 +302,58 @@ class HttpFileFormatter(RequestBase):
                         # TODO not completely works
                         # url escaping is done wrong
                         data = "'" + data.replace("'", "\\'") + "'"
-                    p = f'data({data}{(" ," + mime_type) if mime_type else ""})'
+                    p = f'text({data}{(" ," + mime_type) if mime_type else ""})'
                 if datajson := payload.datajson:
                     parsed_data = json_or_array_to_json(datajson, lambda a: a)
-                    p = f'data({json.dumps(parsed_data, indent=4)})'
+                    p = f'urlencoded({json.dumps(parsed_data, indent=4)})'
                 elif filetype := payload.file:
-                    p = f'fileinput("{filetype}",{(" ," + mime_type) if mime_type else ""})'
+                    p = f'< "{filetype}"  {(" ;" + mime_type) if mime_type else ""}'
                 elif json_data := payload.json:
                     parsed_data = json_or_array_to_json(json_data, lambda a: a)
                     p = f'json({JSON_ENCODER.encode(parsed_data)})'
                 elif files_wrap := payload.fileswrap:
-                    p2 = ",\n\t".join(map(lambda
-                                              file_type: f'("{file_type.name}", "{(file_type.path)}"' +
-                                                         (f' , "{file_type.type}")' if file_type.type else ")"),
+                    def function(multipart):
+                        quote, _ = quote_or_unquote(multipart.path)
+                        multipart_content_type = f' ; {quote}{multipart.type}{quote}' if multipart.type else ""
+                        return f'{quote}{multipart.name}{quote} < {quote}{multipart.path}{quote}{multipart_content_type}'
+
+                    p2 = ",\n\t".join(map(function,
                                           files_wrap.files))
-                    p = f"files({new_line}\t{p2}{new_line})"
+                    p = f"multipart({new_line}\t{p2}{new_line})"
                 output_str += f'{new_line}{p}'
             if output := http.output:
-                output_str += f'{new_line}output({output.output})'
-            output_str += new_line * 3
+                output_str += f'{new_line}>> {output.output}'
+            if http.script_wrap and http.script_wrap.script:
+                output_str += new_line * 2 + "> {%" + new_line * 2 + http.script_wrap.script + new_line * 2 + "%}" + new_line * 3
+            else:
+                output_str += new_line * 3
+            return output_str
+
+    @staticmethod
+    def apply_httpbook(model: Allhttp):
+        arr = []
+        for http in model.allhttps:
+            arr.append({
+                "kind": 2,
+                "language": "dothttp-vscode",
+                "value": HttpFileFormatter.format_http(http),
+                "outputs": []
+            })
+        return json.dumps(arr)
+
+    @staticmethod
+    def apply_http(model: Allhttp):
+        output_str = ""
+        for http in model.allhttps:
+            output_str = output_str + HttpFileFormatter.format_http(http)
         return output_str
 
+    @staticmethod
+    def format(model: Allhttp, filetype=HttpFileType.Httpfile):
+        if filetype == HttpFileType.Httpfile:
+            return HttpFileFormatter.apply_http(model)
+        return HttpFileFormatter.apply_httpbook(model)
+
     def run(self):
         formatted = self.format(self.model)
         if self.args.stdout:
@@ -343,8 +382,29 @@ class RequestCompiler(RequestBase):
             request_logger.error(f"server with url response {resp.status_code}")
             eprint(f"server responded with non 2XX code. code: {resp.status_code}")
         self.print_req_info(resp, '<')
+        self.write_to_output(resp)
+        request_logger.debug(f'request executed completely')
+        script_result = self.execute_script(resp).as_json()
+        self.print_script_result(script_result)
+        return resp
+
+    def print_script_result(self, script_result):
+        print("\n------------")
+        if script_result['stdout']:
+            print("\n##STDOUT:")
+            print(script_result['stdout'])
+        if script_result['error']:
+            print("\n##ERROR:")
+            print(script_result['error'])
+        if len(script_result['properties']) != 0:
+            print("\n##PROPERTIES:")
+            pprint(script_result['properties'])
+        print("\n------------")
+        # TODO print tests output individually
+        request_logger.debug(f'script execution result {script_result}')
+
+    def write_to_output(self, resp):
         output = self.get_output()
-        func = None
         if hasattr(output, 'mode') and 'b' in output.mode:
             func = lambda data: output.write(data)
         else:
@@ -357,19 +417,20 @@ class RequestCompiler(RequestBase):
         except:
             request_logger.warning("not able to close, mostly happens while testing in pycharm")
             eprint("output file close failed")
-        request_logger.debug(f'request executed completely')
-        return resp
 
     def get_response(self):
         session = self.get_session()
         request = self.get_request()
+        session.cookies = request._cookies
         if self.httpdef.p12:
             session.mount(request.url,
                           Pkcs12Adapter(pkcs12_filename=self.httpdef.p12[0],
                                         pkcs12_password=self.httpdef.p12[1]))
         try:
             resp: Response = session.send(request, cert=self.httpdef.certificate,
-                                          verify=not self.httpdef.allow_insecure)
+                                          verify=not self.httpdef.allow_insecure,
+                                          # stream=True
+                                          )
         except UnicodeEncodeError:
             # for Chinese, smiley all other default encode converts into latin-1
             # as latin-1 didn't consist of those characters it will fail
@@ -380,7 +441,10 @@ class RequestCompiler(RequestBase):
             resp: Response = session.send(request, cert=self.httpdef.certificate,
                                           verify=not self.httpdef.allow_insecure)
         if not self.args.no_cookie and isinstance(session.cookies, LWPCookieJar):
-            session.cookies.save()  # lwpCookie has .save method
+            try:
+                session.cookies.save()  # lwpCookie has .save method
+            except:
+                pass
         if self.httpdef.session_clear:
             session.close()
         return resp
@@ -391,6 +455,7 @@ class RequestCompiler(RequestBase):
             # in some cases mimetype can have charset
             # like text/plain; charset=utf-8
             content_type = content_type.split(";")[0] if ';' in content_type else content_type
+            request_logger.debug("script exists. starting script")
             return js3py.execute_script(
                 is_json=content_type == MIME_TYPE_JSON,
                 script=self.httpdef.test_script,
